@@ -32,6 +32,7 @@ typedef struct cffi_generic3 cffi_generic3;
 typedef struct cffi_generic4 cffi_generic4;
 typedef struct cffi_opaque cffi_opaque;
 typedef struct cffi_simpleservice cffi_simpleservice;
+typedef struct cffi_simpleservicelifetime cffi_simpleservicelifetime;
 typedef struct cffi_empty cffi_empty;
 
 typedef enum cffi_ffierror
@@ -126,6 +127,7 @@ typedef struct cffi_weird1u32
 
 typedef uint8_t (*cffi_fptr_fn_u8_rval_u8)(uint8_t x0);
 
+
 typedef uint32_t (*cffi_fptr_fn_u32_rval_u32)(uint32_t x0);
 
 typedef struct cffi_array
@@ -150,10 +152,6 @@ typedef struct cffi_weird2u8
     uint8_t* r;
     } cffi_weird2u8;
 
-typedef cffi_tupled (*cffi_fptr_fn_Tupled_rval_Tupled)(cffi_tupled x0);
-
-typedef bool (*cffi_fptr_fn_pmut_i64_rval_bool)(int64_t* x0);
-
 typedef struct cffi_slicebool
     {
     uint8_t* data;
@@ -172,6 +170,12 @@ typedef struct cffi_sliceu8
     uint64_t len;
     } cffi_sliceu8;
 
+typedef struct cffi_slicemutu32
+    {
+    uint32_t* data;
+    uint64_t len;
+    } cffi_slicemutu32;
+
 typedef struct cffi_slicemutu8
     {
     uint8_t* data;
@@ -184,11 +188,7 @@ typedef struct cffi_optioninner
     uint8_t is_some;
     } cffi_optioninner;
 
-typedef struct cffi_myapiv1
-    {
-    cffi_fptr_fn_pmut_i64_rval_bool ref_mut_option;
-    cffi_fptr_fn_Tupled_rval_Tupled tupled;
-    } cffi_myapiv1;
+typedef void (*cffi_fptr_fn_pconst)(void* x0);
 
 typedef struct cffi_slicevec3f32
     {
@@ -224,17 +224,17 @@ int64_t* ref_mut_simple(int64_t* x);
 bool ref_option(int64_t* x);
 bool ref_mut_option(int64_t* x);
 cffi_tupled tupled(cffi_tupled x);
-cffi_ffierror complex_args_1(cffi_vec3f32 _a, cffi_empty* _b);
-cffi_opaque* complex_args_2(cffi_someforeigntype _cmplx);
+cffi_ffierror complex_args_1(cffi_vec3f32 a, cffi_empty* b);
+cffi_opaque* complex_args_2(cffi_someforeigntype cmplx);
 uint8_t callback(cffi_fptr_fn_u8_rval_u8 callback, uint8_t value);
-uint32_t generic_1a(cffi_genericu32 x, cffi_phantomu8 _y);
-uint8_t generic_1b(cffi_genericu8 x, cffi_phantomu8 _y);
-uint8_t generic_1c(cffi_genericu8* _x, cffi_genericu8* y);
+uint32_t generic_1a(cffi_genericu32 x, cffi_phantomu8 y);
+uint8_t generic_1b(cffi_genericu8 x, cffi_phantomu8 y);
+uint8_t generic_1c(cffi_genericu8* x, cffi_genericu8* y);
 uint8_t generic_2(cffi_generic2u8* x);
 uint8_t generic_3(cffi_generic3* x);
 uint8_t generic_4(cffi_generic4* x);
 uint8_t array_1(cffi_array x);
-cffi_enumdocumented documented(cffi_structdocumented _x);
+cffi_enumdocumented documented(cffi_structdocumented x);
 cffi_vec1 ambiguous_1(cffi_vec1 x);
 cffi_vec2 ambiguous_2(cffi_vec2 x);
 bool ambiguous_3(cffi_vec1 x, cffi_vec2 y);
@@ -242,35 +242,49 @@ cffi_vec namespaced_type(cffi_vec x);
 cffi_ffierror panics();
 cffi_enumrenamed renamed(cffi_structrenamed x);
 void sleep(uint64_t millis);
-bool weird_1(cffi_weird1u32 _x, cffi_weird2u8 _y);
-void visibility(cffi_visibility1 _x, cffi_visibility2 _y);
+bool weird_1(cffi_weird1u32 x, cffi_weird2u8 y);
+void visibility(cffi_visibility1 x, cffi_visibility2 y);
 uint32_t pattern_ascii_pointer_1(uint8_t* x);
+uint8_t* pattern_ascii_pointer_2();
 uint32_t pattern_ascii_pointer_len(uint8_t* x, cffi_useasciistringpattern y);
 uint32_t pattern_ffi_slice_1(cffi_sliceu32 ffi_slice);
 cffi_vec3f32 pattern_ffi_slice_2(cffi_slicevec3f32 ffi_slice, int32_t i);
 void pattern_ffi_slice_3(cffi_slicemutu8 slice, cffi_fptr_fn_SliceMutu8 callback);
-void pattern_ffi_slice_4(cffi_sliceu8 _slice, cffi_slicemutu8 _slice2);
+void pattern_ffi_slice_4(cffi_sliceu8 slice, cffi_slicemutu8 slice2);
 void pattern_ffi_slice_5(cffi_sliceu8* slice, cffi_slicemutu8* slice2);
+void pattern_ffi_slice_6(cffi_slicemutu8* slice, cffi_fptr_fn_u8_rval_u8 callback);
 uint8_t pattern_ffi_slice_delegate(cffi_fptr_fn_Sliceu8_rval_u8 callback);
 cffi_vec3f32 pattern_ffi_slice_delegate_huge(cffi_fptr_fn_SliceVec3f32_rval_Vec3f32 callback);
 cffi_optioninner pattern_ffi_option_1(cffi_optioninner ffi_slice);
 cffi_inner pattern_ffi_option_2(cffi_optioninner ffi_slice);
 uint8_t pattern_ffi_bool(uint8_t ffi_bool);
-void pattern_my_api_init_v1(cffi_myapiv1* api);
 uint64_t pattern_api_guard();
 uint32_t pattern_callback_1(cffi_fptr_fn_u32_rval_u32 callback, uint32_t x);
+cffi_fptr_fn_pconst pattern_callback_2(cffi_fptr_fn_pconst callback);
 cffi_ffierror simple_service_destroy(cffi_simpleservice** context);
 cffi_ffierror simple_service_new_with(cffi_simpleservice** context, uint32_t some_value);
 cffi_ffierror simple_service_new_without(cffi_simpleservice** context);
-cffi_ffierror simple_service_method_result(cffi_simpleservice* context, uint32_t _anon1);
+cffi_ffierror simple_service_new_failing(cffi_simpleservice** context, uint8_t some_value);
+cffi_ffierror simple_service_method_result(cffi_simpleservice* context, uint32_t anon1);
 uint32_t simple_service_method_value(cffi_simpleservice* context, uint32_t x);
 void simple_service_method_void(cffi_simpleservice* context);
 uint8_t simple_service_method_mut_self(cffi_simpleservice* context, cffi_sliceu8 slice);
-void simple_service_method_mut_self_void(cffi_simpleservice* context, cffi_slicebool _slice);
-uint8_t simple_service_method_mut_self_ref(cffi_simpleservice* context, uint8_t* x, uint8_t* _y);
-uint8_t simple_service_method_mut_self_ref_slice(cffi_simpleservice* context, uint8_t* x, uint8_t* _y, cffi_sliceu8 _slice);
-uint8_t simple_service_method_mut_self_ref_slice_limited(cffi_simpleservice* context, uint8_t* x, uint8_t* _y, cffi_sliceu8 _slice, cffi_sliceu8 _slice2);
-cffi_ffierror simple_service_method_mut_self_ffi_error(cffi_simpleservice* context, cffi_slicemutu8 _slice);
+void simple_service_method_mut_self_void(cffi_simpleservice* context, cffi_slicebool slice);
+uint8_t simple_service_method_mut_self_ref(cffi_simpleservice* context, uint8_t* x, uint8_t* y);
+uint8_t simple_service_method_mut_self_ref_slice(cffi_simpleservice* context, uint8_t* x, uint8_t* y, cffi_sliceu8 slice);
+uint8_t simple_service_method_mut_self_ref_slice_limited(cffi_simpleservice* context, uint8_t* x, uint8_t* y, cffi_sliceu8 slice, cffi_sliceu8 slice2);
+cffi_ffierror simple_service_method_mut_self_ffi_error(cffi_simpleservice* context, cffi_slicemutu8 slice);
+cffi_ffierror simple_service_method_mut_self_no_error(cffi_simpleservice* context, cffi_slicemutu8 slice);
+cffi_sliceu32 simple_service_return_slice(cffi_simpleservice* context);
+cffi_slicemutu32 simple_service_return_slice_mut(cffi_simpleservice* context);
+uint8_t* simple_service_return_string(cffi_simpleservice* context);
+cffi_ffierror simple_service_method_void_ffi_error(cffi_simpleservice* context);
+cffi_ffierror simple_service_lt_destroy(cffi_simpleservicelifetime** context);
+cffi_ffierror simple_service_lt_new_with(cffi_simpleservicelifetime** context, uint32_t* some_value);
+void simple_service_lt_method_lt(cffi_simpleservicelifetime* context, cffi_slicebool slice);
+void simple_service_lt_method_lt2(cffi_simpleservicelifetime* context, cffi_slicebool slice);
+uint8_t* simple_service_lt_return_string_accept_slice(cffi_simpleservicelifetime* anon0, cffi_sliceu8 anon1);
+cffi_ffierror simple_service_lt_method_void_ffi_error(cffi_simpleservicelifetime* context);
 """
 
 
@@ -593,48 +607,6 @@ class Inner(CHeapAllocated):
         self._ctx[0].x = value
 
 
-class MyAPIv1(CHeapAllocated):
-    """"""
-    def __init__(self, ref_mut_option = None, tupled = None):
-        self._ctx = ffi.new("cffi_myapiv1[]", 1)
-        if ref_mut_option is not None:
-            self.ref_mut_option = ref_mut_option
-        if tupled is not None:
-            self.tupled = tupled
-
-    @staticmethod
-    def c_array(n: int) -> CArray[MyAPIv1]:
-        return CArray("cffi_myapiv1", n)
-
-    @property
-    def ref_mut_option(self):
-        """"""
-        return self._ctx[0].ref_mut_option
-
-    @ref_mut_option.setter
-    def ref_mut_option(self, value):
-        if hasattr(value, "_ctx"):
-            if hasattr(value, "_c_array"):
-                value = value.c_ptr()
-            else:
-                value = value.c_value()
-        self._ctx[0].ref_mut_option = value
-
-    @property
-    def tupled(self):
-        """"""
-        return self._ctx[0].tupled
-
-    @tupled.setter
-    def tupled(self, value):
-        if hasattr(value, "_ctx"):
-            if hasattr(value, "_c_array"):
-                value = value.c_ptr()
-            else:
-                value = value.c_value()
-        self._ctx[0].tupled = value
-
-
 class Phantomu8(CHeapAllocated):
     """"""
     def __init__(self, x: int = None):
@@ -1153,13 +1125,13 @@ class FFIError:
 
 class callbacks:
     """Helpers to define `@ffi.callback`-style callbacks."""
-    fn_Tupled_rval_Tupled = "cffi_tupled(cffi_tupled)"
-    fn_pmut_i64_rval_bool = "bool(int64_t*)"
     fn_u8_rval_u8 = "uint8_t(uint8_t)"
     fn_Sliceu8_rval_u8 = "uint8_t(cffi_sliceu8)"
     fn_SliceVec3f32_rval_Vec3f32 = "cffi_vec3f32(cffi_slicevec3f32)"
     fn_SliceMutu8 = "void(cffi_slicemutu8)"
+    fn_u8_rval_u8 = "uint8_t(uint8_t)"
     fn_u32_rval_u32 = "uint32_t(uint32_t)"
+    fn_pconst = "void(void*)"
 
 
 class api:
@@ -1358,26 +1330,26 @@ class api:
         return _api.tupled(x)
 
     @staticmethod
-    def complex_args_1(_a: Vec3f32, _b):
+    def complex_args_1(a: Vec3f32, b):
         """"""
-        if hasattr(_a, "_ctx"):
-            _a = _a.c_value()
-        if hasattr(_b, "_ctx"):
-            _b = _b.c_ptr()
+        if hasattr(a, "_ctx"):
+            a = a.c_value()
+        if hasattr(b, "_ctx"):
+            b = b.c_ptr()
 
-        _rval = _api.complex_args_1(_a, _b)
+        _rval = _api.complex_args_1(a, b)
         if _rval == FFIError.Ok:
             return _rval
         else:
             raise Exception(f"Function returned error {_rval}")
 
     @staticmethod
-    def complex_args_2(_cmplx: SomeForeignType):
+    def complex_args_2(cmplx: SomeForeignType):
         """"""
-        if hasattr(_cmplx, "_ctx"):
-            _cmplx = _cmplx.c_value()
+        if hasattr(cmplx, "_ctx"):
+            cmplx = cmplx.c_value()
 
-        return _api.complex_args_2(_cmplx)
+        return _api.complex_args_2(cmplx)
 
     @staticmethod
     def callback(callback, value: int) -> int:
@@ -1395,34 +1367,34 @@ class api:
         return _api.callback(callback, value)
 
     @staticmethod
-    def generic_1a(x: Genericu32, _y: Phantomu8) -> int:
+    def generic_1a(x: Genericu32, y: Phantomu8) -> int:
         """"""
         if hasattr(x, "_ctx"):
             x = x.c_value()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_value()
+        if hasattr(y, "_ctx"):
+            y = y.c_value()
 
-        return _api.generic_1a(x, _y)
+        return _api.generic_1a(x, y)
 
     @staticmethod
-    def generic_1b(x: Genericu8, _y: Phantomu8) -> int:
+    def generic_1b(x: Genericu8, y: Phantomu8) -> int:
         """"""
         if hasattr(x, "_ctx"):
             x = x.c_value()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_value()
+        if hasattr(y, "_ctx"):
+            y = y.c_value()
 
-        return _api.generic_1b(x, _y)
+        return _api.generic_1b(x, y)
 
     @staticmethod
-    def generic_1c(_x, y) -> int:
+    def generic_1c(x, y) -> int:
         """"""
-        if hasattr(_x, "_ctx"):
-            _x = _x.c_ptr()
+        if hasattr(x, "_ctx"):
+            x = x.c_ptr()
         if hasattr(y, "_ctx"):
             y = y.c_ptr()
 
-        return _api.generic_1c(_x, y)
+        return _api.generic_1c(x, y)
 
     @staticmethod
     def generic_2(x) -> int:
@@ -1457,12 +1429,12 @@ class api:
         return _api.array_1(x)
 
     @staticmethod
-    def documented(_x: StructDocumented) -> EnumDocumented:
+    def documented(x: StructDocumented) -> EnumDocumented:
         """ This function has documentation."""
-        if hasattr(_x, "_ctx"):
-            _x = _x.c_value()
+        if hasattr(x, "_ctx"):
+            x = x.c_value()
 
-        return _api.documented(_x)
+        return _api.documented(x)
 
     @staticmethod
     def ambiguous_1(x: Vec1) -> Vec1:
@@ -1525,24 +1497,24 @@ class api:
         return _api.sleep(millis)
 
     @staticmethod
-    def weird_1(_x: Weird1u32, _y: Weird2u8) -> bool:
+    def weird_1(x: Weird1u32, y: Weird2u8) -> bool:
         """"""
-        if hasattr(_x, "_ctx"):
-            _x = _x.c_value()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_value()
+        if hasattr(x, "_ctx"):
+            x = x.c_value()
+        if hasattr(y, "_ctx"):
+            y = y.c_value()
 
-        return _api.weird_1(_x, _y)
+        return _api.weird_1(x, y)
 
     @staticmethod
-    def visibility(_x: Visibility1, _y: Visibility2):
+    def visibility(x: Visibility1, y: Visibility2):
         """"""
-        if hasattr(_x, "_ctx"):
-            _x = _x.c_value()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_value()
+        if hasattr(x, "_ctx"):
+            x = x.c_value()
+        if hasattr(y, "_ctx"):
+            y = y.c_value()
 
-        return _api.visibility(_x, _y)
+        return _api.visibility(x, y)
 
     @staticmethod
     def pattern_ascii_pointer_1(x) -> int:
@@ -1552,6 +1524,12 @@ class api:
 
         return _api.pattern_ascii_pointer_1(x)
 
+    @staticmethod
+    def pattern_ascii_pointer_2():
+        """"""
+
+        return _api.pattern_ascii_pointer_2()
+
     @staticmethod
     def pattern_ascii_pointer_len(x, y: UseAsciiStringPattern) -> int:
         """"""
@@ -1603,18 +1581,18 @@ class api:
         return _api.pattern_ffi_slice_3(slice, callback)
 
     @staticmethod
-    def pattern_ffi_slice_4(_slice, _slice2):
+    def pattern_ffi_slice_4(slice, slice2):
         """"""
-        __slice = ffi.new("cffi_sliceu8[]", 1)
-        __slice[0].data = _slice.c_ptr()
-        __slice[0].len = len(_slice)
-        _slice = __slice[0]
-        __slice2 = ffi.new("cffi_slicemutu8[]", 1)
-        __slice2[0].data = _slice2.c_ptr()
-        __slice2[0].len = len(_slice2)
-        _slice2 = __slice2[0]
+        _slice = ffi.new("cffi_sliceu8[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
+        _slice2 = ffi.new("cffi_slicemutu8[]", 1)
+        _slice2[0].data = slice2.c_ptr()
+        _slice2[0].len = len(slice2)
+        slice2 = _slice2[0]
 
-        return _api.pattern_ffi_slice_4(_slice, _slice2)
+        return _api.pattern_ffi_slice_4(slice, slice2)
 
     @staticmethod
     def pattern_ffi_slice_5(slice, slice2):
@@ -1626,6 +1604,21 @@ class api:
 
         return _api.pattern_ffi_slice_5(slice, slice2)
 
+    @staticmethod
+    def pattern_ffi_slice_6(slice, callback):
+        """"""
+        if hasattr(slice, "_ctx"):
+            slice = slice.c_ptr()
+        _callback = callback
+
+        @ffi.callback(callbacks.fn_u8_rval_u8)
+        def _callback_callback(x):
+            return _callback(x)
+
+        callback = _callback_callback
+
+        return _api.pattern_ffi_slice_6(slice, callback)
+
     @staticmethod
     def pattern_ffi_slice_delegate(callback) -> int:
         """"""
@@ -1678,14 +1671,6 @@ class api:
 
         return _api.pattern_ffi_bool(ffi_bool)
 
-    @staticmethod
-    def pattern_my_api_init_v1(api):
-        """"""
-        if hasattr(api, "_ctx"):
-            api = api.c_ptr()
-
-        return _api.pattern_my_api_init_v1(api)
-
     @staticmethod
     def pattern_api_guard():
         """"""
@@ -1707,6 +1692,19 @@ class api:
 
         return _api.pattern_callback_1(callback, x)
 
+    @staticmethod
+    def pattern_callback_2(callback):
+        """"""
+        _callback = callback
+
+        @ffi.callback(callbacks.fn_pconst)
+        def _callback_callback(ptr):
+            return _callback(ptr)
+
+        callback = _callback_callback
+
+        return _api.pattern_callback_2(callback)
+
     @staticmethod
     def simple_service_destroy(context):
         """ Destroys the given instance.
@@ -1751,15 +1749,29 @@ class api:
             raise Exception(f"Function returned error {_rval}")
 
     @staticmethod
-    def simple_service_method_result(context, _anon1: int):
+    def simple_service_new_failing(context, some_value: int):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value.c_value()
+
+        _rval = _api.simple_service_new_failing(context, some_value)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_method_result(context, anon1: int):
         """ Methods returning a Result<(), _> are the default and do not
  need annotations."""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
-        if hasattr(_anon1, "_ctx"):
-            _anon1 = _anon1.c_value()
+        if hasattr(anon1, "_ctx"):
+            anon1 = anon1.c_value()
 
-        _rval = _api.simple_service_method_result(context, _anon1)
+        _rval = _api.simple_service_method_result(context, anon1)
         if _rval == FFIError.Ok:
             return _rval
         else:
@@ -1798,76 +1810,209 @@ class api:
         return _api.simple_service_method_mut_self(context, slice)
 
     @staticmethod
-    def simple_service_method_mut_self_void(context, _slice):
+    def simple_service_method_mut_self_void(context, slice):
         """ Single line."""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
-        __slice = ffi.new("cffi_slicebool[]", 1)
-        __slice[0].data = _slice.c_ptr()
-        __slice[0].len = len(_slice)
-        _slice = __slice[0]
+        _slice = ffi.new("cffi_slicebool[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
 
-        return _api.simple_service_method_mut_self_void(context, _slice)
+        return _api.simple_service_method_mut_self_void(context, slice)
 
     @staticmethod
-    def simple_service_method_mut_self_ref(context, x, _y) -> int:
+    def simple_service_method_mut_self_ref(context, x, y) -> int:
         """"""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
         if hasattr(x, "_ctx"):
             x = x.c_ptr()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_ptr()
+        if hasattr(y, "_ctx"):
+            y = y.c_ptr()
 
-        return _api.simple_service_method_mut_self_ref(context, x, _y)
+        return _api.simple_service_method_mut_self_ref(context, x, y)
 
     @staticmethod
-    def simple_service_method_mut_self_ref_slice(context, x, _y, _slice) -> int:
+    def simple_service_method_mut_self_ref_slice(context, x, y, slice) -> int:
         """"""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
         if hasattr(x, "_ctx"):
             x = x.c_ptr()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_ptr()
-        __slice = ffi.new("cffi_sliceu8[]", 1)
-        __slice[0].data = _slice.c_ptr()
-        __slice[0].len = len(_slice)
-        _slice = __slice[0]
+        if hasattr(y, "_ctx"):
+            y = y.c_ptr()
+        _slice = ffi.new("cffi_sliceu8[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
 
-        return _api.simple_service_method_mut_self_ref_slice(context, x, _y, _slice)
+        return _api.simple_service_method_mut_self_ref_slice(context, x, y, slice)
 
     @staticmethod
-    def simple_service_method_mut_self_ref_slice_limited(context, x, _y, _slice, _slice2) -> int:
+    def simple_service_method_mut_self_ref_slice_limited(context, x, y, slice, slice2) -> int:
         """"""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
         if hasattr(x, "_ctx"):
             x = x.c_ptr()
-        if hasattr(_y, "_ctx"):
-            _y = _y.c_ptr()
-        __slice = ffi.new("cffi_sliceu8[]", 1)
-        __slice[0].data = _slice.c_ptr()
-        __slice[0].len = len(_slice)
-        _slice = __slice[0]
-        __slice2 = ffi.new("cffi_sliceu8[]", 1)
-        __slice2[0].data = _slice2.c_ptr()
-        __slice2[0].len = len(_slice2)
-        _slice2 = __slice2[0]
+        if hasattr(y, "_ctx"):
+            y = y.c_ptr()
+        _slice = ffi.new("cffi_sliceu8[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
+        _slice2 = ffi.new("cffi_sliceu8[]", 1)
+        _slice2[0].data = slice2.c_ptr()
+        _slice2[0].len = len(slice2)
+        slice2 = _slice2[0]
 
-        return _api.simple_service_method_mut_self_ref_slice_limited(context, x, _y, _slice, _slice2)
+        return _api.simple_service_method_mut_self_ref_slice_limited(context, x, y, slice, slice2)
 
     @staticmethod
-    def simple_service_method_mut_self_ffi_error(context, _slice):
+    def simple_service_method_mut_self_ffi_error(context, slice):
         """"""
         if hasattr(context, "_ctx"):
             context = context.c_ptr()
-        __slice = ffi.new("cffi_slicemutu8[]", 1)
-        __slice[0].data = _slice.c_ptr()
-        __slice[0].len = len(_slice)
-        _slice = __slice[0]
+        _slice = ffi.new("cffi_slicemutu8[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
 
-        _rval = _api.simple_service_method_mut_self_ffi_error(context, _slice)
+        _rval = _api.simple_service_method_mut_self_ffi_error(context, slice)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_method_mut_self_no_error(context, slice):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        _slice = ffi.new("cffi_slicemutu8[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
+
+        _rval = _api.simple_service_method_mut_self_no_error(context, slice)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_return_slice(context):
+        """ Warning, you _must_ discard the returned slice object before calling into this service
+ again, as otherwise undefined behavior might happen."""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        return _api.simple_service_return_slice(context)
+
+    @staticmethod
+    def simple_service_return_slice_mut(context):
+        """ Warning, you _must_ discard the returned slice object before calling into this service
+ again, as otherwise undefined behavior might happen."""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        return _api.simple_service_return_slice_mut(context)
+
+    @staticmethod
+    def simple_service_return_string(context):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        return _api.simple_service_return_string(context)
+
+    @staticmethod
+    def simple_service_method_void_ffi_error(context):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        _rval = _api.simple_service_method_void_ffi_error(context)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_lt_destroy(context):
+        """ Destroys the given instance.
+
+ # Safety
+
+ The passed parameter MUST have been created with the corresponding init function;
+ passing any other value results in undefined behavior."""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        _rval = _api.simple_service_lt_destroy(context)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_lt_new_with(context, some_value):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value.c_ptr()
+
+        _rval = _api.simple_service_lt_new_with(context, some_value)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
+    @staticmethod
+    def simple_service_lt_method_lt(context, slice):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        _slice = ffi.new("cffi_slicebool[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
+
+        return _api.simple_service_lt_method_lt(context, slice)
+
+    @staticmethod
+    def simple_service_lt_method_lt2(context, slice):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        _slice = ffi.new("cffi_slicebool[]", 1)
+        _slice[0].data = slice.c_ptr()
+        _slice[0].len = len(slice)
+        slice = _slice[0]
+
+        return _api.simple_service_lt_method_lt2(context, slice)
+
+    @staticmethod
+    def simple_service_lt_return_string_accept_slice(anon0, anon1):
+        """"""
+        if hasattr(anon0, "_ctx"):
+            anon0 = anon0.c_ptr()
+        _anon1 = ffi.new("cffi_sliceu8[]", 1)
+        _anon1[0].data = anon1.c_ptr()
+        _anon1[0].len = len(anon1)
+        anon1 = _anon1[0]
+
+        return _api.simple_service_lt_return_string_accept_slice(anon0, anon1)
+
+    @staticmethod
+    def simple_service_lt_method_void_ffi_error(context):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+
+        _rval = _api.simple_service_lt_method_void_ffi_error(context)
         if _rval == FFIError.Ok:
             return _rval
         else:
@@ -1878,33 +2023,45 @@ class api:
 class SimpleService(CHeapAllocated):
     __api_lock = object()
 
-    def __init__(self, api_lock):
+    def __init__(self, api_lock, ctx):
         assert(api_lock == SimpleService.__api_lock), "You must create this with a static constructor." 
-        self._ctx = ffi.new("cffi_simpleservice**")
+        self._ctx = ctx
 
     @staticmethod
     def new_with(some_value: int) -> SimpleService:
         """ The constructor must return a `Result<Self, Error>`."""
-        self = SimpleService(SimpleService.__api_lock)
         if hasattr(some_value, "_ctx"):
             some_value = some_value.c_ptr()
-        api.simple_service_new_with(self.c_ptr(), some_value)
+        ctx = ffi.new("cffi_simpleservice**")
+        api.simple_service_new_with(ctx, some_value)
+        self = SimpleService(SimpleService.__api_lock, ctx)
         return self
 
     @staticmethod
     def new_without() -> SimpleService:
         """"""
-        self = SimpleService(SimpleService.__api_lock)
-        api.simple_service_new_without(self.c_ptr(), )
+        ctx = ffi.new("cffi_simpleservice**")
+        api.simple_service_new_without(ctx, )
+        self = SimpleService(SimpleService.__api_lock, ctx)
+        return self
+
+    @staticmethod
+    def new_failing(some_value: int) -> SimpleService:
+        """"""
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value.c_ptr()
+        ctx = ffi.new("cffi_simpleservice**")
+        api.simple_service_new_failing(ctx, some_value)
+        self = SimpleService(SimpleService.__api_lock, ctx)
         return self
 
     def __del__(self):
         api.simple_service_destroy(self.c_ptr(), )
 
-    def method_result(self, _anon1: int):
+    def method_result(self, anon1: int):
         """ Methods returning a Result<(), _> are the default and do not
  need annotations."""
-        return api.simple_service_method_result(self.c_value(), _anon1)
+        return api.simple_service_method_result(self.c_value(), anon1)
 
     def method_value(self, x: int) -> int:
         """"""
@@ -1920,24 +2077,83 @@ class SimpleService(CHeapAllocated):
         """"""
         return api.simple_service_method_mut_self(self.c_value(), slice)
 
-    def method_mut_self_void(self, _slice):
+    def method_mut_self_void(self, slice):
         """ Single line."""
-        return api.simple_service_method_mut_self_void(self.c_value(), _slice)
+        return api.simple_service_method_mut_self_void(self.c_value(), slice)
 
-    def method_mut_self_ref(self, x, _y) -> int:
+    def method_mut_self_ref(self, x, y) -> int:
         """"""
-        return api.simple_service_method_mut_self_ref(self.c_value(), x, _y)
+        return api.simple_service_method_mut_self_ref(self.c_value(), x, y)
 
-    def method_mut_self_ref_slice(self, x, _y, _slice) -> int:
+    def method_mut_self_ref_slice(self, x, y, slice) -> int:
         """"""
-        return api.simple_service_method_mut_self_ref_slice(self.c_value(), x, _y, _slice)
+        return api.simple_service_method_mut_self_ref_slice(self.c_value(), x, y, slice)
 
-    def method_mut_self_ref_slice_limited(self, x, _y, _slice, _slice2) -> int:
+    def method_mut_self_ref_slice_limited(self, x, y, slice, slice2) -> int:
         """"""
-        return api.simple_service_method_mut_self_ref_slice_limited(self.c_value(), x, _y, _slice, _slice2)
+        return api.simple_service_method_mut_self_ref_slice_limited(self.c_value(), x, y, slice, slice2)
 
-    def method_mut_self_ffi_error(self, _slice):
+    def method_mut_self_ffi_error(self, slice):
         """"""
-        return api.simple_service_method_mut_self_ffi_error(self.c_value(), _slice)
+        return api.simple_service_method_mut_self_ffi_error(self.c_value(), slice)
+
+    def method_mut_self_no_error(self, slice):
+        """"""
+        return api.simple_service_method_mut_self_no_error(self.c_value(), slice)
+
+    def return_slice(self, ):
+        """ Warning, you _must_ discard the returned slice object before calling into this service
+ again, as otherwise undefined behavior might happen."""
+        return api.simple_service_return_slice(self.c_value(), )
+
+    def return_slice_mut(self, ):
+        """ Warning, you _must_ discard the returned slice object before calling into this service
+ again, as otherwise undefined behavior might happen."""
+        return api.simple_service_return_slice_mut(self.c_value(), )
+
+    def return_string(self, ):
+        """"""
+        return api.simple_service_return_string(self.c_value(), )
+
+    def method_void_ffi_error(self, ):
+        """"""
+        return api.simple_service_method_void_ffi_error(self.c_value(), )
+
+
+class SimpleServiceLifetime(CHeapAllocated):
+    __api_lock = object()
+
+    def __init__(self, api_lock, ctx):
+        assert(api_lock == SimpleServiceLifetime.__api_lock), "You must create this with a static constructor." 
+        self._ctx = ctx
+
+    @staticmethod
+    def new_with(some_value) -> SimpleServiceLifetime:
+        """"""
+        if hasattr(some_value, "_ctx"):
+            some_value = some_value.c_ptr()
+        ctx = ffi.new("cffi_simpleservicelifetime**")
+        api.simple_service_lt_new_with(ctx, some_value)
+        self = SimpleServiceLifetime(SimpleServiceLifetime.__api_lock, ctx)
+        return self
+
+    def __del__(self):
+        api.simple_service_lt_destroy(self.c_ptr(), )
+
+    def method_lt(self, slice):
+        """"""
+        return api.simple_service_lt_method_lt(self.c_value(), slice)
+
+    def method_lt2(self, slice):
+        """"""
+        return api.simple_service_lt_method_lt2(self.c_value(), slice)
+
+    def return_string_accept_slice(self, anon1):
+        """"""
+        return api.simple_service_lt_return_string_accept_slice(self.c_value(), anon1)
+
+    def method_void_ffi_error(self, ):
+        """"""
+        return api.simple_service_lt_method_void_ffi_error(self.c_value(), )
 
 
